searchData={"items":[{"type":"module","title":"HAP","doc":"HAP is an implementation of the [HomeKit Accessory Protocol](https://developer.apple.com/homekit/) specification.\nIt allows for the creation of Elixir powered HomeKit accessories which can be controlled from a user's\niOS device in a similar manner to commercially available HomeKit accessories such as light bulbs, window\ncoverings and other smart home accessories.","ref":"HAP.html"},{"type":"module","title":"The HomeKit Data Model - HAP","doc":"The data model of the HomeKit Accessory Protocol is represented as a tree structure. At the top level, a single HAP\ninstance represents an *Accessory Server*.  An accessory server hosts one or more *Accessory Objects*. Each accessory object\nrepresents a single, discrete physical accessory. In the case of directly connected devices, an accessory server typically\nhosts a single accessory object which represents device itself, whereas bridges will have one accessory object for each discrete\nphysical object which they bridge to. Within HAP, an accessory server is represented by a `HAP.AccessoryServer` struct, and\nan accessory by the `HAP.Accessory` struct.\n\nEach accessory object contains exposes a set of *Services*, each of which represents a unit of functionality.  As an\nexample, a HomeKit accessory server which represented a ceiling fan with a light would contain one accessory object\ncalled 'Ceiling Fan', which would contain two services each representing the light and the fan. In addition to user-visible\nservices, each accessory exposes an Accessory Information Service which contains information about the service's name,\nmanufacturer, serial number and other properties. Within HAP, a service is represented by a `HAP.Service` struct.\n\nA service is made up of one or more *Characteristics*, each of which represents a specific aspect of the given service.\nFor example, a light bulb service exposes an On Characteristic, which is a boolean value reflecting the current on or\noff state of the light. If it is a dimmable light, it may also expose a Brightness Characteristic. If it is a color\nchanging light, it may also expose a Hue Characteristic. Within HAP, a characteristic is represented by a tuple of a\n`HAP.CharacteristicDefinition` and a value source.","ref":"HAP.html#module-the-homekit-data-model"},{"type":"module","title":"Using HAP - HAP","doc":"HAP provides a high-level interface to the HomeKit Accessory Protocol, allowing an application to\npresent any number of accessories to an iOS HomeKit controller. HAP is intended to be embedded within a host\napplication which is responsible for providing the actual backing implementations of the various characteristics\nexposed via HomeKit. These are provided to HAP in the form of `HAP.ValueStore` implementations.  For example, consider\na Nerves application which exposes itself to HomeKit as a light bulb. Assume that the actual physical control of the\nlight is controlled by GPIO pin 23. A typical configuration of HAP would look something like this:\n\n```elixir\naccessory_server =\n  %HAP.AccessoryServer{\n    name: \"My HAP Demo Device\",\n    model: \"HAP Demo Device\",\n    identifier: \"11:22:33:44:12:66\",\n    accessory_type: 5,\n    accessories: [\n      %HAP.Accessory{\n        name: \"My HAP Lightbulb\",\n        services: [\n          %HAP.Services.LightBulb{on: {MyApp.Lightbulb, gpio_pin: 23}}\n        ]\n      }\n    ]\n  }\n\nchildren = [{HAP, accessory_server}]\n\nSupervisor.start_link(children, opts)\n\n...\n```\n\nIn this example, the application developer is responsible for creating a `MyApp.Lightbulb` module which implements the `HAP.ValueStore`\nbehaviour. This module would be called by HAP whenever it needs to change or query the current state of the light. The\nextra options (`gpio_pin: 23` in the above example) are conveyed to this module on every call, allowing a single value store\nimplementation to service any number of characteristics or services.\n\nHAP provides structs to represent the most common services, such as light bulbs, switches, and other common device types.\nHAP compiles these structs into generic `HAP.Service` structs when starting up, based on each source struct's implementation\nof the `HAP.ServiceSource` protocol. This allows for expressive definition of services by the application developer, while\nproviding for less boilerplate within HAP itself. For users who wish to create additional device types not defined in\nHAP, users may define their accessories in terms of low-level `HAP.Service` and `HAP.CharacteristicDefinition` structs. For more\ninformation, consult the type definitions for `t:HAP.AccessoryServer.t/0`, `t:HAP.Accessory.t/0`, `t:HAP.Service.t/0`,\n`t:HAP.Characteristic.t/0`, and the `HAP.CharacteristicDefinition` behaviour.","ref":"HAP.html#module-using-hap"},{"type":"function","title":"HAP.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"HAP.html#child_spec/1"},{"type":"function","title":"HAP.init/1","doc":"","ref":"HAP.html#init/1"},{"type":"function","title":"HAP.reset/1","doc":"Resets all local state for the given server. Removes all key & state information and allows the\nserver to be paired anew.","ref":"HAP.html#reset/1"},{"type":"function","title":"HAP.start_link/1","doc":"Starts a HAP instance based on the passed config","ref":"HAP.html#start_link/1"},{"type":"function","title":"HAP.value_changed/1","doc":"Called by user applications whenever a characteristic value has changed. The change token is passed to `HAP.ValueStore`\ninstances via the `c:HAP.ValueStore.set_change_token/2` callback.","ref":"HAP.html#value_changed/1"},{"type":"module","title":"HAP.Accessory","doc":"Represents a single accessory object, containing a number of services","ref":"HAP.Accessory.html"},{"type":"type","title":"HAP.Accessory.firmware_revision/0","doc":"The firmware recvision of this accessory, for example '1.0' or '1.0.1'","ref":"HAP.Accessory.html#t:firmware_revision/0"},{"type":"type","title":"HAP.Accessory.manufacturer/0","doc":"The manufacturer of this accessory, for example 'HAP Co.'","ref":"HAP.Accessory.html#t:manufacturer/0"},{"type":"type","title":"HAP.Accessory.model/0","doc":"The model of this accessory, for example 'HAP Light Bulb Supreme'","ref":"HAP.Accessory.html#t:model/0"},{"type":"type","title":"HAP.Accessory.name/0","doc":"The name to advertise for this accessory, for example 'HAP Light Bulb'","ref":"HAP.Accessory.html#t:name/0"},{"type":"type","title":"HAP.Accessory.serial_number/0","doc":"The serial number of this accessory, for example '0012345'","ref":"HAP.Accessory.html#t:serial_number/0"},{"type":"type","title":"HAP.Accessory.t/0","doc":"Represents an accessory consisting of a number of services. Contains the following\nfields:\n\n* `name`: The name to assign to this accessory, for example 'Ceiling Fan'\n* `model`: The model name to assign to this accessory, for example 'FanCo Whisper III'\n* `manufacturer`: The manufacturer of this accessory, for example 'FanCo'\n* `serial_number`: The serial number of this accessory, for example '0012345'\n* `firmware_revision`: The firmware revision of this accessory, for example '1.0'\n* `services`: A list of services to include in this accessory","ref":"HAP.Accessory.html#t:t/0"},{"type":"module","title":"HAP.AccessoryServer","doc":"Represents a top-level HAP instance configuration","ref":"HAP.AccessoryServer.html"},{"type":"function","title":"HAP.AccessoryServer.pairing_url/1","doc":"Generates the pairing url to be used to pair with this accessory server. This \nURL can be encoded in a QR code to enable pairing directly from an iOS device","ref":"HAP.AccessoryServer.html#pairing_url/1"},{"type":"type","title":"HAP.AccessoryServer.accessory_identifier/0","doc":"A unique identifier string in the form \"AA:BB:CC:DD:EE:FF\"","ref":"HAP.AccessoryServer.html#t:accessory_identifier/0"},{"type":"type","title":"HAP.AccessoryServer.accessory_type/0","doc":"A HAP specified value indicating the primary function of this device as found \nin Section 13 of Apple's [HomeKit Accessory Protocol Specification](https://developer.apple.com/homekit/). \nValid values include:\n  1. Other\n  2. Bridge\n  3. Fan\n  4. Garage\n  5. Lightbulb\n  6. Door Lock\n  7. Outlet\n  8. Switch\n  9. Thermostat\n  10. Sensor\n  11. Security System\n  12. Door\n  13. Window\n  14. Window Covering\n  15. Programmable Switch\n  16. Range Extender\n  17. IP Camera\n  18. Video Door Bell\n  19. Air Purifier\n  20. Heater\n  21. Air Conditioner\n  22. Humidifier\n  23. Dehumidifier\n  28. Sprinkler\n  29. Faucet\n  30. Shower System\n  32. Remote","ref":"HAP.AccessoryServer.html#t:accessory_type/0"},{"type":"type","title":"HAP.AccessoryServer.model/0","doc":"The model of this accessory server, for example 'HAP Co. Super Bridge III'","ref":"HAP.AccessoryServer.html#t:model/0"},{"type":"type","title":"HAP.AccessoryServer.name/0","doc":"The name to advertise for this accessory server, for example 'HAP Bridge'","ref":"HAP.AccessoryServer.html#t:name/0"},{"type":"type","title":"HAP.AccessoryServer.pairing_code/0","doc":"A pairing code of the form 123-45-678","ref":"HAP.AccessoryServer.html#t:pairing_code/0"},{"type":"type","title":"HAP.AccessoryServer.pairing_url/0","doc":"A pairing URL suitable for display in a QR code","ref":"HAP.AccessoryServer.html#t:pairing_url/0"},{"type":"type","title":"HAP.AccessoryServer.setup_id/0","doc":"A 4 character string used as part of the accessory discovery process","ref":"HAP.AccessoryServer.html#t:setup_id/0"},{"type":"type","title":"HAP.AccessoryServer.t/0","doc":"Represents an accessory server consisting of a number of accessories. Contains the following fields:\n\n* `name`: The name to assign to this device, for example 'HAP Bridge'\n* `model`: The model name to assign to this device, for example 'HAP Co. Super Bridge III'\n* `identifier`: A unique identifier string in the form \"AA:BB:CC:DD:EE:FF\"\n* `pairing_code`: A pairing code of the form 123-45-678 to be used for pairing. \nIf not specified one will be defined dynamically.\n* `setup_id`: A 4 character string used as part of the accessory discovery process. \nIf not specified one will be defined dynamically.\n* `display_module`: An optional implementation of `HAP.Display` used to present pairing \nand other information to the user. If not specified then a basic console-based\ndisplay is used.\n* `data_path`: The path to where HAP will store its internal data. Will be created if\nit does not exist. If not specified, the default value depends on the value of `Mix.target/0`.\nIf it is `:host` then a value of `hap_data` is used. If it is anything else (as it will be\nwhen compiling for a Nerves target, for example), the value of `/root/hap_data` is used. This\nallows HAP to work out-of-the-box in conventional and Nerves environments.\n* `accessory_type`: A HAP specified value indicating the primary function of this \ndevice. See `t:HAP.AccessoryServer.accessory_type/0` for details\n* `accessories`: A list of `HAP.Accessory` structs to include in this accessory server","ref":"HAP.AccessoryServer.html#t:t/0"},{"type":"behaviour","title":"HAP.Display","doc":"A behaviour which encapsulates all user-facing display concerns for an accessory.  Applications which use HAP may\nprovide their own implementation of this behaviour as a field in a `HAP.AccessoryServer`. If no such\nimplementation is provided HAP uses a default console based implementation","ref":"HAP.Display.html"},{"type":"callback","title":"HAP.Display.clear_pairing_code/0","doc":"Stop displaying any currently displayed pairing information to the user. This is\nmost commonly because a pairing has been established with a controller","ref":"HAP.Display.html#c:clear_pairing_code/0"},{"type":"callback","title":"HAP.Display.display_pairing_code/3","doc":"Display a notification to the user containing information on how to pair with\nthis accessory server. The value of `pairing_url` can be encoded in a QR code\nto enable pairing directly from an iOS device.","ref":"HAP.Display.html#c:display_pairing_code/3"},{"type":"callback","title":"HAP.Display.identify/1","doc":"Display a notification to the user that identifies the named device or accessory.\nThis comes from a user request within the Home app to identify the given device \nor accessory.","ref":"HAP.Display.html#c:identify/1"},{"type":"behaviour","title":"HAP.ValueStore","doc":"Defines the behaviour required of a module that wishes to act as the backing data store\nfor a given HomeKit characteristic\n\n# Simple Value Store\n\nTo implement a value store for a simple value whose value does not change asynchronously,\nyou must implement the `c:get_value/1` and `c:put_value/2` callbacks. These callbacks each \ntake a set of opts (specified in the initial configuration passed to `HAP.start_link/1`) to\nallow your implementation to discriminate between various values within the same `HAP.ValueStore` \nmodule.\n\n# Supporting Asynchronous Notifications\n\nTo support notifying HomeKit of changes to an accessory's characteristics (such as a user pressing\na button or a flood sensor detecting water), implementations of `HAP.ValueStore` may choose to \nimplement the optional `c:set_change_token/2` callback. This callback will provide your implementation\nwith a change token to use when notifying HAP of changes to the corresponding value. To notify HAP of\nchanges to a value, pass this change token to the `HAP.value_changed/1` function. HAP will then query \nyour value store for the new value of the corresponding characteristic and notify any HomeKit controllers\nof the change.\n\nThere are a number of things to be aware of when using Asynchronous Notifications:\n\n* Your value store must be prepared to answer calls to `c:get_value/1` with the updated value before\ncalling `HAP.value_changed/1`.\n* Do not call `HAP.value_changed/1` to notify HAP of changes which come from HAP itself (ie: do not call it in the course \nof implementing `c:put_value/2`). Use it only for notifying HAP of changes which are truly asynchronous.\n* If you have not yet received a `c:set_change_token/2` call, then you should not call `HAP.value_changed/1`; HAP will only\nprovide you with a change token for characteristics which a HomeKit controller has requested notifications on. Specifically, \ndo not retain change tokens between runs; they should maintain the same lifetime as the underlying HAP process.\n* The call to `HAP.value_changed/1` is guaranteed to return quickly. It does no work beyond casting a message\nto HAP to set the notification process in motion.","ref":"HAP.ValueStore.html"},{"type":"callback","title":"HAP.ValueStore.get_value/1","doc":"Return the value of a value hosted by this value store. The passed list of opts\nis as specified in the hosting `HAP.Configuration` and can be used to distinguish a\nparticular value within a larger value store (perhaps by GPIO pin or similar)\n\nReturns the value stored by this value store","ref":"HAP.ValueStore.html#c:get_value/1"},{"type":"callback","title":"HAP.ValueStore.put_value/2","doc":"Sets the value of a value hosted by this value store. The passed list of opts\nis as specified in the hosting `HAP.Configuration` and can be used to distinguish a\nparticular value within a larger value store (perhaps by GPIO pin or similar)\n\nReturns `:ok` or `{:error, reason}`","ref":"HAP.ValueStore.html#c:put_value/2"},{"type":"callback","title":"HAP.ValueStore.set_change_token/2","doc":"Informs the value store of the change token to use when notifying HAP of asynchronous \nchanges to the value in this store. This token should be provided to `HAP.value_changed/1` as the \nsole argument; HAP will make a subsequent call to `c:get_value/1` to obtain the changed value\n\nReturns `:ok` or `{:error, reason}`","ref":"HAP.ValueStore.html#c:set_change_token/2"},{"type":"opaque","title":"HAP.ValueStore.change_token/0","doc":"","ref":"HAP.ValueStore.html#t:change_token/0"},{"type":"type","title":"HAP.ValueStore.opts/0","doc":"","ref":"HAP.ValueStore.html#t:opts/0"},{"type":"type","title":"HAP.ValueStore.t/0","doc":"","ref":"HAP.ValueStore.html#t:t/0"},{"type":"module","title":"HAP.Service","doc":"Represents a single service, containing a number of characteristics","ref":"HAP.Service.html"},{"type":"type","title":"HAP.Service.t/0","doc":"Represents a service of a given type, containing a number of characteristics","ref":"HAP.Service.html#t:t/0"},{"type":"type","title":"HAP.Service.type/0","doc":"The type of a service as defined in Section 6.6.1 of Apple's [HomeKit Accessory Protocol Specification](https://developer.apple.com/homekit/).","ref":"HAP.Service.html#t:type/0"},{"type":"protocol","title":"HAP.ServiceSource","doc":"A protocol which allows for arbitrary service definitions to compile themselves into `HAP.Service` structs\nfor use within HAP. This protocol allows HAP to expose pre-defined services such as `HAP.Services.Lightbulb`\nwith fields reflecting the domain of the service, while allowing HAP to work internally with a service tree \nclose to that defined in the HomeKit specification","ref":"HAP.ServiceSource.html"},{"type":"function","title":"HAP.ServiceSource.compile/1","doc":"Compile the given value into a `HAP.Service` struct","ref":"HAP.ServiceSource.html#compile/1"},{"type":"type","title":"HAP.ServiceSource.t/0","doc":"All the types that implement this protocol.","ref":"HAP.ServiceSource.html#t:t/0"},{"type":"module","title":"HAP.Services.AccessoryInformation","doc":"Struct representing an instance of the `public.hap.service.accessory-information` service","ref":"HAP.Services.AccessoryInformation.html"},{"type":"module","title":"HAP.Services.AirPurifier","doc":"Struct representing an instance of the `public.hap.service.air-purifier` service","ref":"HAP.Services.AirPurifier.html"},{"type":"module","title":"HAP.Services.AirQualitySensor","doc":"Struct representing an instance of the `public.hap.service.sensor.air-quality` service","ref":"HAP.Services.AirQualitySensor.html"},{"type":"module","title":"HAP.Services.CarbonDioxideSensor","doc":"Struct representing an instance of the `public.hap.service.sensor.carbon-dioxide` service","ref":"HAP.Services.CarbonDioxideSensor.html"},{"type":"module","title":"HAP.Services.CarbonMonoxideSensor","doc":"Struct representing an instance of the `public.hap.service.sensor.carbon-monoxide` service","ref":"HAP.Services.CarbonMonoxideSensor.html"},{"type":"module","title":"HAP.Services.ContactSensor","doc":"Struct representing an instance of the `public.hap.service.sensor.contact` service","ref":"HAP.Services.ContactSensor.html"},{"type":"module","title":"HAP.Services.Door","doc":"Struct representing an instance of the `public.hap.service.door` service","ref":"HAP.Services.Door.html"},{"type":"module","title":"HAP.Services.DoorBell","doc":"Struct representing an instance of the `public.hap.service.doorbell` service","ref":"HAP.Services.DoorBell.html"},{"type":"module","title":"HAP.Services.FanV2","doc":"Struct representing an instance of the `public.hap.service.fanv2` service","ref":"HAP.Services.FanV2.html"},{"type":"module","title":"HAP.Services.Faucet","doc":"Struct representing an instance of the `public.hap.service.faucet` service","ref":"HAP.Services.Faucet.html"},{"type":"module","title":"HAP.Services.GarageDoor","doc":"Struct representing an instance of 'public.hap.service.garage_door.opener' service","ref":"HAP.Services.GarageDoor.html"},{"type":"module","title":"HAP.Services.HeaterCooler","doc":"Struct representing an instance of the `public.hap.service.heater-cooler` service","ref":"HAP.Services.HeaterCooler.html"},{"type":"module","title":"HAP.Services.HumiditySensor","doc":"Struct representing an instance of the `public.hap.service.sensor.humidity` service","ref":"HAP.Services.HumiditySensor.html"},{"type":"module","title":"HAP.Services.LeakSensor","doc":"Struct representing an instance of the `public.hap.service.sensor.leak` service","ref":"HAP.Services.LeakSensor.html"},{"type":"module","title":"HAP.Services.LightBulb","doc":"Struct representing an instance of the `public.hap.service.lightbulb` service","ref":"HAP.Services.LightBulb.html"},{"type":"module","title":"HAP.Services.LightSensor","doc":"Struct representing an instance of the `public.hap.service.sensor.light` service","ref":"HAP.Services.LightSensor.html"},{"type":"module","title":"HAP.Services.Microphone","doc":"Struct representing an instance of the `public.hap.service.microphone` service","ref":"HAP.Services.Microphone.html"},{"type":"module","title":"HAP.Services.MotionSensor","doc":"Struct representing an instance of the `public.hap.service.sensor.motion` service","ref":"HAP.Services.MotionSensor.html"},{"type":"module","title":"HAP.Services.OccupancySensor","doc":"Struct representing an instance of the `public.hap.service.sensor.occupancy` service","ref":"HAP.Services.OccupancySensor.html"},{"type":"module","title":"HAP.Services.Outlet","doc":"Struct representing an instance of the `public.hap.service.outlet` service","ref":"HAP.Services.Outlet.html"},{"type":"module","title":"HAP.Services.ProtocolInformation","doc":"Struct representing an instance of the `public.hap.service.protocol.information.service` service","ref":"HAP.Services.ProtocolInformation.html"},{"type":"module","title":"HAP.Services.ServiceLabel","doc":"Struct representing an instance of the `public.hap.service.service-label` service","ref":"HAP.Services.ServiceLabel.html"},{"type":"module","title":"HAP.Services.Slat","doc":"Struct representing an instance of the `public.hap.service.vertical-slat` service","ref":"HAP.Services.Slat.html"},{"type":"module","title":"HAP.Services.SmokeSensor","doc":"Struct representing an instance of the `public.hap.service.sensor.smoke` service","ref":"HAP.Services.SmokeSensor.html"},{"type":"module","title":"HAP.Services.Speaker","doc":"Struct representing an instance of the `public.hap.service.speaker` service","ref":"HAP.Services.Speaker.html"},{"type":"module","title":"HAP.Services.StatelessProgrammableSwitch","doc":"Struct representing an instance of the `public.hap.service.stateless-programmable-switch` service\n\nNOTE special requirements in specification for using Service Label (index) under various circumstances","ref":"HAP.Services.StatelessProgrammableSwitch.html"},{"type":"module","title":"HAP.Services.Switch","doc":"Struct representing an instance of the `public.hap.service.switch` service","ref":"HAP.Services.Switch.html"},{"type":"module","title":"HAP.Services.TemperatureSensor","doc":"Struct representing an instance of the `public.hap.service.sensor.temperature` service","ref":"HAP.Services.TemperatureSensor.html"},{"type":"module","title":"HAP.Services.Thermostat","doc":"Struct representing an instance of the `public.hap.service.thermostat` service","ref":"HAP.Services.Thermostat.html"},{"type":"module","title":"HAP.Services.Window","doc":"Struct representing an instance of the `public.hap.service.window` service","ref":"HAP.Services.Window.html"},{"type":"module","title":"HAP.Services.WindowCovering","doc":"Struct representing an instance of the `public.hap.service.window-covering` service","ref":"HAP.Services.WindowCovering.html"},{"type":"module","title":"HAP.Characteristic","doc":"Functions to aid in the manipulation of characteristics tuples","ref":"HAP.Characteristic.html"},{"type":"type","title":"HAP.Characteristic.t/0","doc":"Represents a single characteristic consisting of a static definition and a value source","ref":"HAP.Characteristic.html#t:t/0"},{"type":"type","title":"HAP.Characteristic.value/0","doc":"The resolved value of a characteristic","ref":"HAP.Characteristic.html#t:value/0"},{"type":"type","title":"HAP.Characteristic.value_source/0","doc":"Represents a source for a characteristic value. May be either a static literal or \na `{mod, opts}` tuple which is consulted when reading / writing a characteristic","ref":"HAP.Characteristic.html#t:value_source/0"},{"type":"behaviour","title":"HAP.CharacteristicDefinition","doc":"A behaviour which encapsulates the functinos required to define a characteristic. \nAt runtime, characteristics are modeled via the `HAP.Characteristic` struct which\ncontains the runtime values for the characteristic itself, as well as metadata about\nthe characteristic. A `HAP.CharacteristicDefinition` is used to provide the template\nvalues for these fields. HAP contains definitions for many common HomeKit characteristics\nalready, and users may define other characteristics by providing an implementation of\nthis behaviour as the first value in the characteristic definition tuple in a service.","ref":"HAP.CharacteristicDefinition.html"},{"type":"callback","title":"HAP.CharacteristicDefinition.event_only/0","doc":"Whether or not to only return values via events. Required mostly to satisfy the somewhat oddball *Programmable Switch Event*\ncharacteristic as defined in section 9.75 of Apple's [HomeKit Accessory Protocol Specification](https://developer.apple.com/homekit/).","ref":"HAP.CharacteristicDefinition.html#c:event_only/0"},{"type":"callback","title":"HAP.CharacteristicDefinition.format/0","doc":"The format of this characteristic's data","ref":"HAP.CharacteristicDefinition.html#c:format/0"},{"type":"callback","title":"HAP.CharacteristicDefinition.max_value/0","doc":"The maximum value allowed for this characteristic's value","ref":"HAP.CharacteristicDefinition.html#c:max_value/0"},{"type":"callback","title":"HAP.CharacteristicDefinition.min_value/0","doc":"The minimum value allowed for this characteristic's value","ref":"HAP.CharacteristicDefinition.html#c:min_value/0"},{"type":"callback","title":"HAP.CharacteristicDefinition.perms/0","doc":"The permissions to allow for this characteristic","ref":"HAP.CharacteristicDefinition.html#c:perms/0"},{"type":"callback","title":"HAP.CharacteristicDefinition.step_value/0","doc":"The step size by which this characteristic's value may change","ref":"HAP.CharacteristicDefinition.html#c:step_value/0"},{"type":"callback","title":"HAP.CharacteristicDefinition.type/0","doc":"The HomeKit type code for this characteristic","ref":"HAP.CharacteristicDefinition.html#c:type/0"},{"type":"callback","title":"HAP.CharacteristicDefinition.units/0","doc":"The units of this Characteristic's value","ref":"HAP.CharacteristicDefinition.html#c:units/0"},{"type":"type","title":"HAP.CharacteristicDefinition.format/0","doc":"The format of a characteristic as defined in Table 6.5 of Apple's [HomeKit Accessory Protocol Specification](https://developer.apple.com/homekit/).\nOne of `bool`, `uint8`, `uint16`, `uint32`, `uint64`, `int`, `float`, `string`, `tlv8`, or `data`","ref":"HAP.CharacteristicDefinition.html#t:format/0"},{"type":"type","title":"HAP.CharacteristicDefinition.perm/0","doc":"A permission of a characteristic as defined in Table 6.4 of Apple's [HomeKit Accessory Protocol Specification](https://developer.apple.com/homekit/).\nOne of `pr`, `pw`, `ev`, `aa`, `tw`, `hd`, or `wr`","ref":"HAP.CharacteristicDefinition.html#t:perm/0"},{"type":"type","title":"HAP.CharacteristicDefinition.type/0","doc":"The type of a characteristic as defined in Section 6.6.1 of Apple's [HomeKit Accessory Protocol Specification](https://developer.apple.com/homekit/).","ref":"HAP.CharacteristicDefinition.html#t:type/0"},{"type":"type","title":"HAP.CharacteristicDefinition.unit/0","doc":"The unit of measure of a characrteristic's value","ref":"HAP.CharacteristicDefinition.html#t:unit/0"},{"type":"module","title":"HAP.Characteristics.Active","doc":"Definition of the `public.hap.characteristic.active` characteristic","ref":"HAP.Characteristics.Active.html"},{"type":"function","title":"HAP.Characteristics.Active.format/0","doc":"","ref":"HAP.Characteristics.Active.html#format/0"},{"type":"function","title":"HAP.Characteristics.Active.max_value/0","doc":"","ref":"HAP.Characteristics.Active.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.Active.min_value/0","doc":"","ref":"HAP.Characteristics.Active.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.Active.perms/0","doc":"","ref":"HAP.Characteristics.Active.html#perms/0"},{"type":"function","title":"HAP.Characteristics.Active.step_value/0","doc":"","ref":"HAP.Characteristics.Active.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.Active.type/0","doc":"","ref":"HAP.Characteristics.Active.html#type/0"},{"type":"module","title":"HAP.Characteristics.AirQuality","doc":"Definition of the `public.hap.characteristic.air-quality` characteristic\n\nValid values:\n\n0 Unknown\n1 Excellent\n2 Good\n3 Fair\n4 Inferior\n5 Poor","ref":"HAP.Characteristics.AirQuality.html"},{"type":"function","title":"HAP.Characteristics.AirQuality.format/0","doc":"","ref":"HAP.Characteristics.AirQuality.html#format/0"},{"type":"function","title":"HAP.Characteristics.AirQuality.max_value/0","doc":"","ref":"HAP.Characteristics.AirQuality.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.AirQuality.min_value/0","doc":"","ref":"HAP.Characteristics.AirQuality.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.AirQuality.perms/0","doc":"","ref":"HAP.Characteristics.AirQuality.html#perms/0"},{"type":"function","title":"HAP.Characteristics.AirQuality.step_value/0","doc":"","ref":"HAP.Characteristics.AirQuality.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.AirQuality.type/0","doc":"","ref":"HAP.Characteristics.AirQuality.html#type/0"},{"type":"module","title":"HAP.Characteristics.Brightness","doc":"Definition of the `public.hap.characteristic.brightness` characteristic","ref":"HAP.Characteristics.Brightness.html"},{"type":"function","title":"HAP.Characteristics.Brightness.format/0","doc":"","ref":"HAP.Characteristics.Brightness.html#format/0"},{"type":"function","title":"HAP.Characteristics.Brightness.max_value/0","doc":"","ref":"HAP.Characteristics.Brightness.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.Brightness.min_value/0","doc":"","ref":"HAP.Characteristics.Brightness.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.Brightness.perms/0","doc":"","ref":"HAP.Characteristics.Brightness.html#perms/0"},{"type":"function","title":"HAP.Characteristics.Brightness.step_value/0","doc":"","ref":"HAP.Characteristics.Brightness.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.Brightness.type/0","doc":"","ref":"HAP.Characteristics.Brightness.html#type/0"},{"type":"function","title":"HAP.Characteristics.Brightness.unit/0","doc":"","ref":"HAP.Characteristics.Brightness.html#unit/0"},{"type":"module","title":"HAP.Characteristics.CarbonDioxideDetected","doc":"Definition of the `public.hap.characteristic.carbon-dioxide.detected` characteristic\n\nValid values:\n0: Carbon Dioxide levels are normal\n1: Carbon Dioxide levels are abnormal","ref":"HAP.Characteristics.CarbonDioxideDetected.html"},{"type":"function","title":"HAP.Characteristics.CarbonDioxideDetected.format/0","doc":"","ref":"HAP.Characteristics.CarbonDioxideDetected.html#format/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxideDetected.max_value/0","doc":"","ref":"HAP.Characteristics.CarbonDioxideDetected.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxideDetected.min_value/0","doc":"","ref":"HAP.Characteristics.CarbonDioxideDetected.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxideDetected.perms/0","doc":"","ref":"HAP.Characteristics.CarbonDioxideDetected.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxideDetected.step_value/0","doc":"","ref":"HAP.Characteristics.CarbonDioxideDetected.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxideDetected.type/0","doc":"","ref":"HAP.Characteristics.CarbonDioxideDetected.html#type/0"},{"type":"module","title":"HAP.Characteristics.CarbonDioxideLevel","doc":"Definition of the `public.hap.characteristic.carbon-dioxide.level` characteristic","ref":"HAP.Characteristics.CarbonDioxideLevel.html"},{"type":"function","title":"HAP.Characteristics.CarbonDioxideLevel.format/0","doc":"","ref":"HAP.Characteristics.CarbonDioxideLevel.html#format/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxideLevel.max_value/0","doc":"","ref":"HAP.Characteristics.CarbonDioxideLevel.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxideLevel.min_value/0","doc":"","ref":"HAP.Characteristics.CarbonDioxideLevel.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxideLevel.perms/0","doc":"","ref":"HAP.Characteristics.CarbonDioxideLevel.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxideLevel.type/0","doc":"","ref":"HAP.Characteristics.CarbonDioxideLevel.html#type/0"},{"type":"module","title":"HAP.Characteristics.CarbonDioxidePeakLevel","doc":"Definition of the `public.hap.characteristic.carbon-dioxide.peak-level` characteristic","ref":"HAP.Characteristics.CarbonDioxidePeakLevel.html"},{"type":"function","title":"HAP.Characteristics.CarbonDioxidePeakLevel.format/0","doc":"","ref":"HAP.Characteristics.CarbonDioxidePeakLevel.html#format/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxidePeakLevel.max_value/0","doc":"","ref":"HAP.Characteristics.CarbonDioxidePeakLevel.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxidePeakLevel.min_value/0","doc":"","ref":"HAP.Characteristics.CarbonDioxidePeakLevel.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxidePeakLevel.perms/0","doc":"","ref":"HAP.Characteristics.CarbonDioxidePeakLevel.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CarbonDioxidePeakLevel.type/0","doc":"","ref":"HAP.Characteristics.CarbonDioxidePeakLevel.html#type/0"},{"type":"module","title":"HAP.Characteristics.CarbonMonoxideDetected","doc":"Definition of the `public.hap.characteristic.carbon-monoxide.detected` characteristic\n\nValid values:\n0: Carbon Monoxide levels are normal\n1: Carbon Monoxide levels are abnormal","ref":"HAP.Characteristics.CarbonMonoxideDetected.html"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxideDetected.format/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxideDetected.html#format/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxideDetected.max_value/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxideDetected.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxideDetected.min_value/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxideDetected.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxideDetected.perms/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxideDetected.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxideDetected.step_value/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxideDetected.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxideDetected.type/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxideDetected.html#type/0"},{"type":"module","title":"HAP.Characteristics.CarbonMonoxideLevel","doc":"Definition of the `public.hap.characteristic.carbon-monoxide.level` characteristic","ref":"HAP.Characteristics.CarbonMonoxideLevel.html"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxideLevel.format/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxideLevel.html#format/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxideLevel.max_value/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxideLevel.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxideLevel.min_value/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxideLevel.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxideLevel.perms/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxideLevel.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxideLevel.type/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxideLevel.html#type/0"},{"type":"module","title":"HAP.Characteristics.CarbonMonoxidePeakLevel","doc":"Definition of the `public.hap.characteristic.carbon-monoxide.peak-level` characteristic","ref":"HAP.Characteristics.CarbonMonoxidePeakLevel.html"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxidePeakLevel.format/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxidePeakLevel.html#format/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxidePeakLevel.max_value/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxidePeakLevel.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxidePeakLevel.min_value/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxidePeakLevel.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxidePeakLevel.perms/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxidePeakLevel.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CarbonMonoxidePeakLevel.type/0","doc":"","ref":"HAP.Characteristics.CarbonMonoxidePeakLevel.html#type/0"},{"type":"module","title":"HAP.Characteristics.ColorTemperature","doc":"Definition of the `public.hap.characteristic.color-temperature` characteristic\n\nThis characteristic describes color temperature which is represented in reciprocal \nmegaKelvin (MK-1) or mirek scale. (M = 1,000,000 / K where M is the desired mirek \nvalue and K is temperature in Kelvin)","ref":"HAP.Characteristics.ColorTemperature.html"},{"type":"function","title":"HAP.Characteristics.ColorTemperature.format/0","doc":"","ref":"HAP.Characteristics.ColorTemperature.html#format/0"},{"type":"function","title":"HAP.Characteristics.ColorTemperature.max_value/0","doc":"","ref":"HAP.Characteristics.ColorTemperature.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.ColorTemperature.min_value/0","doc":"","ref":"HAP.Characteristics.ColorTemperature.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.ColorTemperature.perms/0","doc":"","ref":"HAP.Characteristics.ColorTemperature.html#perms/0"},{"type":"function","title":"HAP.Characteristics.ColorTemperature.step_value/0","doc":"","ref":"HAP.Characteristics.ColorTemperature.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.ColorTemperature.type/0","doc":"","ref":"HAP.Characteristics.ColorTemperature.html#type/0"},{"type":"module","title":"HAP.Characteristics.ContactSensorState","doc":"Definition of the `public.hap.characteristic.contact-state` characteristic\n\nA value of 0 indicates that the contact is detected. A value of 1 indicates \nthat the contact is not detected.","ref":"HAP.Characteristics.ContactSensorState.html"},{"type":"function","title":"HAP.Characteristics.ContactSensorState.format/0","doc":"","ref":"HAP.Characteristics.ContactSensorState.html#format/0"},{"type":"function","title":"HAP.Characteristics.ContactSensorState.max_value/0","doc":"","ref":"HAP.Characteristics.ContactSensorState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.ContactSensorState.min_value/0","doc":"","ref":"HAP.Characteristics.ContactSensorState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.ContactSensorState.perms/0","doc":"","ref":"HAP.Characteristics.ContactSensorState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.ContactSensorState.step_value/0","doc":"","ref":"HAP.Characteristics.ContactSensorState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.ContactSensorState.type/0","doc":"","ref":"HAP.Characteristics.ContactSensorState.html#type/0"},{"type":"module","title":"HAP.Characteristics.CoolingThresholdTemperature","doc":"Definition of the `public.hap.characteristic.temperature.cooling-threshold` characteristic","ref":"HAP.Characteristics.CoolingThresholdTemperature.html"},{"type":"function","title":"HAP.Characteristics.CoolingThresholdTemperature.format/0","doc":"","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#format/0"},{"type":"function","title":"HAP.Characteristics.CoolingThresholdTemperature.max_value/0","doc":"","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CoolingThresholdTemperature.min_value/0","doc":"","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CoolingThresholdTemperature.perms/0","doc":"","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CoolingThresholdTemperature.step_value/0","doc":"","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CoolingThresholdTemperature.type/0","doc":"","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#type/0"},{"type":"function","title":"HAP.Characteristics.CoolingThresholdTemperature.units/0","doc":"","ref":"HAP.Characteristics.CoolingThresholdTemperature.html#units/0"},{"type":"module","title":"HAP.Characteristics.CurrentAirPurifierState","doc":"Definition of the `public.hap.characteristic.air-purifier.state.current` characteristic\n\nValid values:\n\n0 Inactive\n1 Idle\n2 Purifying Air","ref":"HAP.Characteristics.CurrentAirPurifierState.html"},{"type":"function","title":"HAP.Characteristics.CurrentAirPurifierState.format/0","doc":"","ref":"HAP.Characteristics.CurrentAirPurifierState.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentAirPurifierState.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentAirPurifierState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentAirPurifierState.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentAirPurifierState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentAirPurifierState.perms/0","doc":"","ref":"HAP.Characteristics.CurrentAirPurifierState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentAirPurifierState.step_value/0","doc":"","ref":"HAP.Characteristics.CurrentAirPurifierState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentAirPurifierState.type/0","doc":"","ref":"HAP.Characteristics.CurrentAirPurifierState.html#type/0"},{"type":"module","title":"HAP.Characteristics.CurrentAmbientLightLevel","doc":"Definition of the `public.hap.characteristic.light-level.current` characteristic","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html"},{"type":"function","title":"HAP.Characteristics.CurrentAmbientLightLevel.format/0","doc":"","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentAmbientLightLevel.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentAmbientLightLevel.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentAmbientLightLevel.perms/0","doc":"","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentAmbientLightLevel.type/0","doc":"","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html#type/0"},{"type":"function","title":"HAP.Characteristics.CurrentAmbientLightLevel.units/0","doc":"","ref":"HAP.Characteristics.CurrentAmbientLightLevel.html#units/0"},{"type":"module","title":"HAP.Characteristics.CurrentDoorState","doc":"Definition of the `public.hap.characteristic.door-state.current` characteristic\n\nValid values:\n\n0 Open    - The door is fully open\n1 Closed  - The door is fully closed\n2 Opening - The door is actively opening\n3 Closing - The door is actively closing\n4 Stopped - The door is not moving, and it is not fully open nor fully closed","ref":"HAP.Characteristics.CurrentDoorState.html"},{"type":"function","title":"HAP.Characteristics.CurrentDoorState.format/0","doc":"","ref":"HAP.Characteristics.CurrentDoorState.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentDoorState.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentDoorState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentDoorState.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentDoorState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentDoorState.perms/0","doc":"","ref":"HAP.Characteristics.CurrentDoorState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentDoorState.step_value/0","doc":"","ref":"HAP.Characteristics.CurrentDoorState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentDoorState.type/0","doc":"","ref":"HAP.Characteristics.CurrentDoorState.html#type/0"},{"type":"module","title":"HAP.Characteristics.CurrentFanState","doc":"Definition of the `public.hap.characteristic.fan.state.current` characteristic\n\nValid values:\n\n0 Inactive\n1 Idle\n2 Blowing Air","ref":"HAP.Characteristics.CurrentFanState.html"},{"type":"function","title":"HAP.Characteristics.CurrentFanState.format/0","doc":"","ref":"HAP.Characteristics.CurrentFanState.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentFanState.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentFanState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentFanState.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentFanState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentFanState.perms/0","doc":"","ref":"HAP.Characteristics.CurrentFanState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentFanState.step_value/0","doc":"","ref":"HAP.Characteristics.CurrentFanState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentFanState.type/0","doc":"","ref":"HAP.Characteristics.CurrentFanState.html#type/0"},{"type":"module","title":"HAP.Characteristics.CurrentHeaterCoolerState","doc":"Definition of the `public.hap.characteristic.heater-cooler.state.current` characteristic\n\nValid values:\n\n0 Inactive\n1 Idle\n2 Heating\n3 Cooling","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html"},{"type":"function","title":"HAP.Characteristics.CurrentHeaterCoolerState.format/0","doc":"","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentHeaterCoolerState.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentHeaterCoolerState.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentHeaterCoolerState.perms/0","doc":"","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentHeaterCoolerState.step_value/0","doc":"","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentHeaterCoolerState.type/0","doc":"","ref":"HAP.Characteristics.CurrentHeaterCoolerState.html#type/0"},{"type":"module","title":"HAP.Characteristics.CurrentHeatingCoolingState","doc":"Definition of the `public.hap.characteristic.heating-cooling.state.current` characteristic\n\nValid values:\n\n0 Off\n1 Heating\n2 Cooling","ref":"HAP.Characteristics.CurrentHeatingCoolingState.html"},{"type":"function","title":"HAP.Characteristics.CurrentHeatingCoolingState.format/0","doc":"","ref":"HAP.Characteristics.CurrentHeatingCoolingState.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentHeatingCoolingState.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentHeatingCoolingState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentHeatingCoolingState.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentHeatingCoolingState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentHeatingCoolingState.perms/0","doc":"","ref":"HAP.Characteristics.CurrentHeatingCoolingState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentHeatingCoolingState.step_value/0","doc":"","ref":"HAP.Characteristics.CurrentHeatingCoolingState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentHeatingCoolingState.type/0","doc":"","ref":"HAP.Characteristics.CurrentHeatingCoolingState.html#type/0"},{"type":"module","title":"HAP.Characteristics.CurrentHorizontalTiltAngle","doc":"Definition of the `public.hap.characteristic.horizontal-tilt.current` characteristic","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html"},{"type":"function","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.format/0","doc":"","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.perms/0","doc":"","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.step_value/0","doc":"","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.type/0","doc":"","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#type/0"},{"type":"function","title":"HAP.Characteristics.CurrentHorizontalTiltAngle.units/0","doc":"","ref":"HAP.Characteristics.CurrentHorizontalTiltAngle.html#units/0"},{"type":"module","title":"HAP.Characteristics.CurrentPosition","doc":"Definition of the `public.hap.characteristic.position.current` characteristic","ref":"HAP.Characteristics.CurrentPosition.html"},{"type":"function","title":"HAP.Characteristics.CurrentPosition.format/0","doc":"","ref":"HAP.Characteristics.CurrentPosition.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentPosition.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentPosition.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentPosition.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentPosition.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentPosition.perms/0","doc":"","ref":"HAP.Characteristics.CurrentPosition.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentPosition.step_value/0","doc":"","ref":"HAP.Characteristics.CurrentPosition.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentPosition.type/0","doc":"","ref":"HAP.Characteristics.CurrentPosition.html#type/0"},{"type":"function","title":"HAP.Characteristics.CurrentPosition.unit/0","doc":"","ref":"HAP.Characteristics.CurrentPosition.html#unit/0"},{"type":"module","title":"HAP.Characteristics.CurrentRelativeHumidity","doc":"Definition of the `public.hap.characteristic.relative-humidity.current` characteristic","ref":"HAP.Characteristics.CurrentRelativeHumidity.html"},{"type":"function","title":"HAP.Characteristics.CurrentRelativeHumidity.format/0","doc":"","ref":"HAP.Characteristics.CurrentRelativeHumidity.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentRelativeHumidity.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentRelativeHumidity.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentRelativeHumidity.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentRelativeHumidity.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentRelativeHumidity.perms/0","doc":"","ref":"HAP.Characteristics.CurrentRelativeHumidity.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentRelativeHumidity.step_value/0","doc":"","ref":"HAP.Characteristics.CurrentRelativeHumidity.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentRelativeHumidity.type/0","doc":"","ref":"HAP.Characteristics.CurrentRelativeHumidity.html#type/0"},{"type":"function","title":"HAP.Characteristics.CurrentRelativeHumidity.unit/0","doc":"","ref":"HAP.Characteristics.CurrentRelativeHumidity.html#unit/0"},{"type":"module","title":"HAP.Characteristics.CurrentSlatState","doc":"Definition of the `public.hap.characteristic.slat.state.current` characteristic\n\nValid values:\n\n0 Fixed\n1 Jammed\n2 Swinging","ref":"HAP.Characteristics.CurrentSlatState.html"},{"type":"function","title":"HAP.Characteristics.CurrentSlatState.format/0","doc":"","ref":"HAP.Characteristics.CurrentSlatState.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentSlatState.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentSlatState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentSlatState.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentSlatState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentSlatState.perms/0","doc":"","ref":"HAP.Characteristics.CurrentSlatState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentSlatState.step_value/0","doc":"","ref":"HAP.Characteristics.CurrentSlatState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentSlatState.type/0","doc":"","ref":"HAP.Characteristics.CurrentSlatState.html#type/0"},{"type":"module","title":"HAP.Characteristics.CurrentTemperature","doc":"Definition of the `public.hap.characteristic.temperature.current` characteristic","ref":"HAP.Characteristics.CurrentTemperature.html"},{"type":"function","title":"HAP.Characteristics.CurrentTemperature.format/0","doc":"","ref":"HAP.Characteristics.CurrentTemperature.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentTemperature.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentTemperature.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentTemperature.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentTemperature.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentTemperature.perms/0","doc":"","ref":"HAP.Characteristics.CurrentTemperature.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentTemperature.step_value/0","doc":"","ref":"HAP.Characteristics.CurrentTemperature.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentTemperature.type/0","doc":"","ref":"HAP.Characteristics.CurrentTemperature.html#type/0"},{"type":"function","title":"HAP.Characteristics.CurrentTemperature.unit/0","doc":"","ref":"HAP.Characteristics.CurrentTemperature.html#unit/0"},{"type":"module","title":"HAP.Characteristics.CurrentTiltAngle","doc":"Definition of the `public.hap.characteristic.tilt.current` characteristic","ref":"HAP.Characteristics.CurrentTiltAngle.html"},{"type":"function","title":"HAP.Characteristics.CurrentTiltAngle.format/0","doc":"","ref":"HAP.Characteristics.CurrentTiltAngle.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentTiltAngle.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentTiltAngle.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentTiltAngle.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentTiltAngle.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentTiltAngle.perms/0","doc":"","ref":"HAP.Characteristics.CurrentTiltAngle.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentTiltAngle.step_value/0","doc":"","ref":"HAP.Characteristics.CurrentTiltAngle.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentTiltAngle.type/0","doc":"","ref":"HAP.Characteristics.CurrentTiltAngle.html#type/0"},{"type":"function","title":"HAP.Characteristics.CurrentTiltAngle.units/0","doc":"","ref":"HAP.Characteristics.CurrentTiltAngle.html#units/0"},{"type":"module","title":"HAP.Characteristics.CurrentVerticalTiltAngle","doc":"Definition of the `public.hap.characteristic.vertical-tilt.current` characteristic","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html"},{"type":"function","title":"HAP.Characteristics.CurrentVerticalTiltAngle.format/0","doc":"","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#format/0"},{"type":"function","title":"HAP.Characteristics.CurrentVerticalTiltAngle.max_value/0","doc":"","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentVerticalTiltAngle.min_value/0","doc":"","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentVerticalTiltAngle.perms/0","doc":"","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#perms/0"},{"type":"function","title":"HAP.Characteristics.CurrentVerticalTiltAngle.step_value/0","doc":"","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.CurrentVerticalTiltAngle.type/0","doc":"","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#type/0"},{"type":"function","title":"HAP.Characteristics.CurrentVerticalTiltAngle.units/0","doc":"","ref":"HAP.Characteristics.CurrentVerticalTiltAngle.html#units/0"},{"type":"module","title":"HAP.Characteristics.FirmwareRevision","doc":"Definition of the `public.hap.characteristic.firmware.revision` characteristic","ref":"HAP.Characteristics.FirmwareRevision.html"},{"type":"function","title":"HAP.Characteristics.FirmwareRevision.format/0","doc":"","ref":"HAP.Characteristics.FirmwareRevision.html#format/0"},{"type":"function","title":"HAP.Characteristics.FirmwareRevision.perms/0","doc":"","ref":"HAP.Characteristics.FirmwareRevision.html#perms/0"},{"type":"function","title":"HAP.Characteristics.FirmwareRevision.type/0","doc":"","ref":"HAP.Characteristics.FirmwareRevision.html#type/0"},{"type":"module","title":"HAP.Characteristics.HeatingThresholdTemperature","doc":"Definition of the `public.hap.characteristic.temperature.heating-threshold` characteristic","ref":"HAP.Characteristics.HeatingThresholdTemperature.html"},{"type":"function","title":"HAP.Characteristics.HeatingThresholdTemperature.format/0","doc":"","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#format/0"},{"type":"function","title":"HAP.Characteristics.HeatingThresholdTemperature.max_value/0","doc":"","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.HeatingThresholdTemperature.min_value/0","doc":"","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.HeatingThresholdTemperature.perms/0","doc":"","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#perms/0"},{"type":"function","title":"HAP.Characteristics.HeatingThresholdTemperature.step_value/0","doc":"","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.HeatingThresholdTemperature.type/0","doc":"","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#type/0"},{"type":"function","title":"HAP.Characteristics.HeatingThresholdTemperature.units/0","doc":"","ref":"HAP.Characteristics.HeatingThresholdTemperature.html#units/0"},{"type":"module","title":"HAP.Characteristics.HoldPosition","doc":"Definition of the `public.hap.characteristic.position.hold` characteristic","ref":"HAP.Characteristics.HoldPosition.html"},{"type":"function","title":"HAP.Characteristics.HoldPosition.format/0","doc":"","ref":"HAP.Characteristics.HoldPosition.html#format/0"},{"type":"function","title":"HAP.Characteristics.HoldPosition.perms/0","doc":"","ref":"HAP.Characteristics.HoldPosition.html#perms/0"},{"type":"function","title":"HAP.Characteristics.HoldPosition.type/0","doc":"","ref":"HAP.Characteristics.HoldPosition.html#type/0"},{"type":"module","title":"HAP.Characteristics.Hue","doc":"Definition of the `public.hap.characteristic.hue` characteristic","ref":"HAP.Characteristics.Hue.html"},{"type":"function","title":"HAP.Characteristics.Hue.format/0","doc":"","ref":"HAP.Characteristics.Hue.html#format/0"},{"type":"function","title":"HAP.Characteristics.Hue.max_value/0","doc":"","ref":"HAP.Characteristics.Hue.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.Hue.min_value/0","doc":"","ref":"HAP.Characteristics.Hue.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.Hue.perms/0","doc":"","ref":"HAP.Characteristics.Hue.html#perms/0"},{"type":"function","title":"HAP.Characteristics.Hue.step_value/0","doc":"","ref":"HAP.Characteristics.Hue.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.Hue.type/0","doc":"","ref":"HAP.Characteristics.Hue.html#type/0"},{"type":"function","title":"HAP.Characteristics.Hue.unit/0","doc":"","ref":"HAP.Characteristics.Hue.html#unit/0"},{"type":"module","title":"HAP.Characteristics.Identify","doc":"Definition of the `public.hap.characteristic.identify` characteristic","ref":"HAP.Characteristics.Identify.html"},{"type":"function","title":"HAP.Characteristics.Identify.format/0","doc":"","ref":"HAP.Characteristics.Identify.html#format/0"},{"type":"function","title":"HAP.Characteristics.Identify.perms/0","doc":"","ref":"HAP.Characteristics.Identify.html#perms/0"},{"type":"function","title":"HAP.Characteristics.Identify.type/0","doc":"","ref":"HAP.Characteristics.Identify.html#type/0"},{"type":"module","title":"HAP.Characteristics.InputEvent","doc":"Definition of the `public.hap.characteristic.input-event` characteristic\n\nValid values:\n0 ”Single Press”\n1 ”Double Press”\n2 ”Long Press”\n\nNOTE specification requirement:\nFor IP accessories, the accessory must set the value of Paired Read to null(i.e. ”value” : null) in the attribute database. A read of this characteristic must always return a null value for IP accessories.\n\nThe value must only be reported in the events (”ev”) property.","ref":"HAP.Characteristics.InputEvent.html"},{"type":"function","title":"HAP.Characteristics.InputEvent.event_only/0","doc":"","ref":"HAP.Characteristics.InputEvent.html#event_only/0"},{"type":"function","title":"HAP.Characteristics.InputEvent.format/0","doc":"","ref":"HAP.Characteristics.InputEvent.html#format/0"},{"type":"function","title":"HAP.Characteristics.InputEvent.max_value/0","doc":"","ref":"HAP.Characteristics.InputEvent.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.InputEvent.min_value/0","doc":"","ref":"HAP.Characteristics.InputEvent.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.InputEvent.perms/0","doc":"","ref":"HAP.Characteristics.InputEvent.html#perms/0"},{"type":"function","title":"HAP.Characteristics.InputEvent.step_value/0","doc":"","ref":"HAP.Characteristics.InputEvent.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.InputEvent.type/0","doc":"","ref":"HAP.Characteristics.InputEvent.html#type/0"},{"type":"module","title":"HAP.Characteristics.LeakDetected","doc":"Definition of the `public.hap.characteristic.leak-detected` characteristic\n\nValid values: \n0: Leak is not detected\n1: Leak is detected","ref":"HAP.Characteristics.LeakDetected.html"},{"type":"function","title":"HAP.Characteristics.LeakDetected.format/0","doc":"","ref":"HAP.Characteristics.LeakDetected.html#format/0"},{"type":"function","title":"HAP.Characteristics.LeakDetected.max_value/0","doc":"","ref":"HAP.Characteristics.LeakDetected.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.LeakDetected.min_value/0","doc":"","ref":"HAP.Characteristics.LeakDetected.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.LeakDetected.perms/0","doc":"","ref":"HAP.Characteristics.LeakDetected.html#perms/0"},{"type":"function","title":"HAP.Characteristics.LeakDetected.step_value/0","doc":"","ref":"HAP.Characteristics.LeakDetected.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.LeakDetected.type/0","doc":"","ref":"HAP.Characteristics.LeakDetected.html#type/0"},{"type":"module","title":"HAP.Characteristics.LockCurrentState","doc":"Definition of the `public.hap.characteristic.lock-mechanism.current-state` characteristic\n\nValid values:\n\n0 Unsecured \n1 Secured\n2 Jammed\n3 Unknowm","ref":"HAP.Characteristics.LockCurrentState.html"},{"type":"function","title":"HAP.Characteristics.LockCurrentState.format/0","doc":"","ref":"HAP.Characteristics.LockCurrentState.html#format/0"},{"type":"function","title":"HAP.Characteristics.LockCurrentState.max_value/0","doc":"","ref":"HAP.Characteristics.LockCurrentState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.LockCurrentState.min_value/0","doc":"","ref":"HAP.Characteristics.LockCurrentState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.LockCurrentState.perms/0","doc":"","ref":"HAP.Characteristics.LockCurrentState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.LockCurrentState.step_value/0","doc":"","ref":"HAP.Characteristics.LockCurrentState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.LockCurrentState.type/0","doc":"","ref":"HAP.Characteristics.LockCurrentState.html#type/0"},{"type":"module","title":"HAP.Characteristics.LockPhysicalControls","doc":"Definition of the `public.hap.characteristic.lock-physical-controls` characteristic\n\nValid values: \n\n0: Control lock disabled\n1: Control lock enabled","ref":"HAP.Characteristics.LockPhysicalControls.html"},{"type":"function","title":"HAP.Characteristics.LockPhysicalControls.format/0","doc":"","ref":"HAP.Characteristics.LockPhysicalControls.html#format/0"},{"type":"function","title":"HAP.Characteristics.LockPhysicalControls.max_value/0","doc":"","ref":"HAP.Characteristics.LockPhysicalControls.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.LockPhysicalControls.min_value/0","doc":"","ref":"HAP.Characteristics.LockPhysicalControls.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.LockPhysicalControls.perms/0","doc":"","ref":"HAP.Characteristics.LockPhysicalControls.html#perms/0"},{"type":"function","title":"HAP.Characteristics.LockPhysicalControls.step_value/0","doc":"","ref":"HAP.Characteristics.LockPhysicalControls.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.LockPhysicalControls.type/0","doc":"","ref":"HAP.Characteristics.LockPhysicalControls.html#type/0"},{"type":"module","title":"HAP.Characteristics.LockTargetState","doc":"Definition of the `public.hap.characteristic.lock-mechanism.target-state` characteristic\n\nValid values:\n\n0 Unsecured \n1 Secured","ref":"HAP.Characteristics.LockTargetState.html"},{"type":"function","title":"HAP.Characteristics.LockTargetState.format/0","doc":"","ref":"HAP.Characteristics.LockTargetState.html#format/0"},{"type":"function","title":"HAP.Characteristics.LockTargetState.max_value/0","doc":"","ref":"HAP.Characteristics.LockTargetState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.LockTargetState.min_value/0","doc":"","ref":"HAP.Characteristics.LockTargetState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.LockTargetState.perms/0","doc":"","ref":"HAP.Characteristics.LockTargetState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.LockTargetState.step_value/0","doc":"","ref":"HAP.Characteristics.LockTargetState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.LockTargetState.type/0","doc":"","ref":"HAP.Characteristics.LockTargetState.html#type/0"},{"type":"module","title":"HAP.Characteristics.Manufacturer","doc":"Definition of the `public.hap.characteristic.manufacturer` characteristic","ref":"HAP.Characteristics.Manufacturer.html"},{"type":"function","title":"HAP.Characteristics.Manufacturer.format/0","doc":"","ref":"HAP.Characteristics.Manufacturer.html#format/0"},{"type":"function","title":"HAP.Characteristics.Manufacturer.max_length/0","doc":"","ref":"HAP.Characteristics.Manufacturer.html#max_length/0"},{"type":"function","title":"HAP.Characteristics.Manufacturer.perms/0","doc":"","ref":"HAP.Characteristics.Manufacturer.html#perms/0"},{"type":"function","title":"HAP.Characteristics.Manufacturer.type/0","doc":"","ref":"HAP.Characteristics.Manufacturer.html#type/0"},{"type":"module","title":"HAP.Characteristics.Model","doc":"Definition of the `public.hap.characteristic.model` characteristic","ref":"HAP.Characteristics.Model.html"},{"type":"function","title":"HAP.Characteristics.Model.format/0","doc":"","ref":"HAP.Characteristics.Model.html#format/0"},{"type":"function","title":"HAP.Characteristics.Model.max_length/0","doc":"","ref":"HAP.Characteristics.Model.html#max_length/0"},{"type":"function","title":"HAP.Characteristics.Model.perms/0","doc":"","ref":"HAP.Characteristics.Model.html#perms/0"},{"type":"function","title":"HAP.Characteristics.Model.type/0","doc":"","ref":"HAP.Characteristics.Model.html#type/0"},{"type":"module","title":"HAP.Characteristics.MotionDetected","doc":"Definition of the `public.hap.characteristic.motion-detected` characteristic","ref":"HAP.Characteristics.MotionDetected.html"},{"type":"function","title":"HAP.Characteristics.MotionDetected.format/0","doc":"","ref":"HAP.Characteristics.MotionDetected.html#format/0"},{"type":"function","title":"HAP.Characteristics.MotionDetected.perms/0","doc":"","ref":"HAP.Characteristics.MotionDetected.html#perms/0"},{"type":"function","title":"HAP.Characteristics.MotionDetected.type/0","doc":"","ref":"HAP.Characteristics.MotionDetected.html#type/0"},{"type":"module","title":"HAP.Characteristics.Mute","doc":"Definition of the `public.hap.characteristic.mute` characteristic\n# Valid Values\n#\n# 0 ”Mute is Off / Audio is On”\n# 1 ”Mute is On / There is no Audio”","ref":"HAP.Characteristics.Mute.html"},{"type":"function","title":"HAP.Characteristics.Mute.format/0","doc":"","ref":"HAP.Characteristics.Mute.html#format/0"},{"type":"function","title":"HAP.Characteristics.Mute.perms/0","doc":"","ref":"HAP.Characteristics.Mute.html#perms/0"},{"type":"function","title":"HAP.Characteristics.Mute.type/0","doc":"","ref":"HAP.Characteristics.Mute.html#type/0"},{"type":"module","title":"HAP.Characteristics.Name","doc":"Definition of the `public.hap.characteristic.name` characteristic","ref":"HAP.Characteristics.Name.html"},{"type":"function","title":"HAP.Characteristics.Name.format/0","doc":"","ref":"HAP.Characteristics.Name.html#format/0"},{"type":"function","title":"HAP.Characteristics.Name.max_length/0","doc":"","ref":"HAP.Characteristics.Name.html#max_length/0"},{"type":"function","title":"HAP.Characteristics.Name.perms/0","doc":"","ref":"HAP.Characteristics.Name.html#perms/0"},{"type":"function","title":"HAP.Characteristics.Name.type/0","doc":"","ref":"HAP.Characteristics.Name.html#type/0"},{"type":"module","title":"HAP.Characteristics.NitrogenDioxideDensity","doc":"Definition of the `public.hap.characteristic.density.no2` characteristic","ref":"HAP.Characteristics.NitrogenDioxideDensity.html"},{"type":"function","title":"HAP.Characteristics.NitrogenDioxideDensity.format/0","doc":"","ref":"HAP.Characteristics.NitrogenDioxideDensity.html#format/0"},{"type":"function","title":"HAP.Characteristics.NitrogenDioxideDensity.max_value/0","doc":"","ref":"HAP.Characteristics.NitrogenDioxideDensity.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.NitrogenDioxideDensity.min_value/0","doc":"","ref":"HAP.Characteristics.NitrogenDioxideDensity.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.NitrogenDioxideDensity.perms/0","doc":"","ref":"HAP.Characteristics.NitrogenDioxideDensity.html#perms/0"},{"type":"function","title":"HAP.Characteristics.NitrogenDioxideDensity.type/0","doc":"","ref":"HAP.Characteristics.NitrogenDioxideDensity.html#type/0"},{"type":"module","title":"HAP.Characteristics.ObstructionDetected","doc":"Definition of the `public.hap.characteristic.obstruction-detected` characteristic","ref":"HAP.Characteristics.ObstructionDetected.html"},{"type":"function","title":"HAP.Characteristics.ObstructionDetected.format/0","doc":"","ref":"HAP.Characteristics.ObstructionDetected.html#format/0"},{"type":"function","title":"HAP.Characteristics.ObstructionDetected.perms/0","doc":"","ref":"HAP.Characteristics.ObstructionDetected.html#perms/0"},{"type":"function","title":"HAP.Characteristics.ObstructionDetected.type/0","doc":"","ref":"HAP.Characteristics.ObstructionDetected.html#type/0"},{"type":"module","title":"HAP.Characteristics.OccupancyDetected","doc":"Definition of the `public.hap.characteristic.occupancy-detected` characteristic\n\nValid values: \n0: Occupancy is not detected\n1: Occupancy is detected","ref":"HAP.Characteristics.OccupancyDetected.html"},{"type":"function","title":"HAP.Characteristics.OccupancyDetected.format/0","doc":"","ref":"HAP.Characteristics.OccupancyDetected.html#format/0"},{"type":"function","title":"HAP.Characteristics.OccupancyDetected.max_value/0","doc":"","ref":"HAP.Characteristics.OccupancyDetected.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.OccupancyDetected.min_value/0","doc":"","ref":"HAP.Characteristics.OccupancyDetected.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.OccupancyDetected.perms/0","doc":"","ref":"HAP.Characteristics.OccupancyDetected.html#perms/0"},{"type":"function","title":"HAP.Characteristics.OccupancyDetected.step_value/0","doc":"","ref":"HAP.Characteristics.OccupancyDetected.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.OccupancyDetected.type/0","doc":"","ref":"HAP.Characteristics.OccupancyDetected.html#type/0"},{"type":"module","title":"HAP.Characteristics.On","doc":"Definition of the `public.hap.characteristic.on` characteristic","ref":"HAP.Characteristics.On.html"},{"type":"function","title":"HAP.Characteristics.On.format/0","doc":"","ref":"HAP.Characteristics.On.html#format/0"},{"type":"function","title":"HAP.Characteristics.On.perms/0","doc":"","ref":"HAP.Characteristics.On.html#perms/0"},{"type":"function","title":"HAP.Characteristics.On.type/0","doc":"","ref":"HAP.Characteristics.On.html#type/0"},{"type":"module","title":"HAP.Characteristics.OutletInUse","doc":"Definition of the `public.hap.characteristic.outlet-in-use` characteristic","ref":"HAP.Characteristics.OutletInUse.html"},{"type":"function","title":"HAP.Characteristics.OutletInUse.format/0","doc":"","ref":"HAP.Characteristics.OutletInUse.html#format/0"},{"type":"function","title":"HAP.Characteristics.OutletInUse.perms/0","doc":"","ref":"HAP.Characteristics.OutletInUse.html#perms/0"},{"type":"function","title":"HAP.Characteristics.OutletInUse.type/0","doc":"","ref":"HAP.Characteristics.OutletInUse.html#type/0"},{"type":"module","title":"HAP.Characteristics.OzoneDensity","doc":"Definition of the `public.hap.characteristic.density.ozone` characteristic","ref":"HAP.Characteristics.OzoneDensity.html"},{"type":"function","title":"HAP.Characteristics.OzoneDensity.format/0","doc":"","ref":"HAP.Characteristics.OzoneDensity.html#format/0"},{"type":"function","title":"HAP.Characteristics.OzoneDensity.max_value/0","doc":"","ref":"HAP.Characteristics.OzoneDensity.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.OzoneDensity.min_value/0","doc":"","ref":"HAP.Characteristics.OzoneDensity.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.OzoneDensity.perms/0","doc":"","ref":"HAP.Characteristics.OzoneDensity.html#perms/0"},{"type":"function","title":"HAP.Characteristics.OzoneDensity.type/0","doc":"","ref":"HAP.Characteristics.OzoneDensity.html#type/0"},{"type":"module","title":"HAP.Characteristics.PM10Density","doc":"Definition of the `public.hap.characteristic.density.pm10` characteristic","ref":"HAP.Characteristics.PM10Density.html"},{"type":"function","title":"HAP.Characteristics.PM10Density.format/0","doc":"","ref":"HAP.Characteristics.PM10Density.html#format/0"},{"type":"function","title":"HAP.Characteristics.PM10Density.max_value/0","doc":"","ref":"HAP.Characteristics.PM10Density.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.PM10Density.min_value/0","doc":"","ref":"HAP.Characteristics.PM10Density.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.PM10Density.perms/0","doc":"","ref":"HAP.Characteristics.PM10Density.html#perms/0"},{"type":"function","title":"HAP.Characteristics.PM10Density.type/0","doc":"","ref":"HAP.Characteristics.PM10Density.html#type/0"},{"type":"module","title":"HAP.Characteristics.PM25Density","doc":"Definition of the `public.hap.characteristic.density.pm2_5` characteristic","ref":"HAP.Characteristics.PM25Density.html"},{"type":"function","title":"HAP.Characteristics.PM25Density.format/0","doc":"","ref":"HAP.Characteristics.PM25Density.html#format/0"},{"type":"function","title":"HAP.Characteristics.PM25Density.max_value/0","doc":"","ref":"HAP.Characteristics.PM25Density.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.PM25Density.min_value/0","doc":"","ref":"HAP.Characteristics.PM25Density.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.PM25Density.perms/0","doc":"","ref":"HAP.Characteristics.PM25Density.html#perms/0"},{"type":"function","title":"HAP.Characteristics.PM25Density.type/0","doc":"","ref":"HAP.Characteristics.PM25Density.html#type/0"},{"type":"module","title":"HAP.Characteristics.PositionState","doc":"Definition of the `public.hap.characteristic.position.state` characteristic\n\nValid values:\n0: Going to the minimum value specified in metadata\n1: Going to the maximum value specified in metadata\n2: Stopped","ref":"HAP.Characteristics.PositionState.html"},{"type":"function","title":"HAP.Characteristics.PositionState.format/0","doc":"","ref":"HAP.Characteristics.PositionState.html#format/0"},{"type":"function","title":"HAP.Characteristics.PositionState.max_value/0","doc":"","ref":"HAP.Characteristics.PositionState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.PositionState.min_value/0","doc":"","ref":"HAP.Characteristics.PositionState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.PositionState.perms/0","doc":"","ref":"HAP.Characteristics.PositionState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.PositionState.step_value/0","doc":"","ref":"HAP.Characteristics.PositionState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.PositionState.type/0","doc":"","ref":"HAP.Characteristics.PositionState.html#type/0"},{"type":"module","title":"HAP.Characteristics.RotationDirection","doc":"Definition of the `public.hap.characteristic.rotation.direction` characteristic\n\nValid values\n\n0 Clockwise\n1 Counter-clockwise\n2-255 Reserved","ref":"HAP.Characteristics.RotationDirection.html"},{"type":"function","title":"HAP.Characteristics.RotationDirection.format/0","doc":"","ref":"HAP.Characteristics.RotationDirection.html#format/0"},{"type":"function","title":"HAP.Characteristics.RotationDirection.max_value/0","doc":"","ref":"HAP.Characteristics.RotationDirection.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.RotationDirection.min_value/0","doc":"","ref":"HAP.Characteristics.RotationDirection.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.RotationDirection.perms/0","doc":"","ref":"HAP.Characteristics.RotationDirection.html#perms/0"},{"type":"function","title":"HAP.Characteristics.RotationDirection.step_value/0","doc":"","ref":"HAP.Characteristics.RotationDirection.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.RotationDirection.type/0","doc":"","ref":"HAP.Characteristics.RotationDirection.html#type/0"},{"type":"module","title":"HAP.Characteristics.RotationSpeed","doc":"Definition of the `public.hap.characteristic.rotation.speed` characteristic","ref":"HAP.Characteristics.RotationSpeed.html"},{"type":"function","title":"HAP.Characteristics.RotationSpeed.format/0","doc":"","ref":"HAP.Characteristics.RotationSpeed.html#format/0"},{"type":"function","title":"HAP.Characteristics.RotationSpeed.max_value/0","doc":"","ref":"HAP.Characteristics.RotationSpeed.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.RotationSpeed.min_value/0","doc":"","ref":"HAP.Characteristics.RotationSpeed.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.RotationSpeed.perms/0","doc":"","ref":"HAP.Characteristics.RotationSpeed.html#perms/0"},{"type":"function","title":"HAP.Characteristics.RotationSpeed.step_value/0","doc":"","ref":"HAP.Characteristics.RotationSpeed.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.RotationSpeed.type/0","doc":"","ref":"HAP.Characteristics.RotationSpeed.html#type/0"},{"type":"function","title":"HAP.Characteristics.RotationSpeed.unit/0","doc":"","ref":"HAP.Characteristics.RotationSpeed.html#unit/0"},{"type":"module","title":"HAP.Characteristics.Saturation","doc":"Definition of the `public.hap.characteristic.saturation` characteristic","ref":"HAP.Characteristics.Saturation.html"},{"type":"function","title":"HAP.Characteristics.Saturation.format/0","doc":"","ref":"HAP.Characteristics.Saturation.html#format/0"},{"type":"function","title":"HAP.Characteristics.Saturation.max_value/0","doc":"","ref":"HAP.Characteristics.Saturation.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.Saturation.min_value/0","doc":"","ref":"HAP.Characteristics.Saturation.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.Saturation.perms/0","doc":"","ref":"HAP.Characteristics.Saturation.html#perms/0"},{"type":"function","title":"HAP.Characteristics.Saturation.step_value/0","doc":"","ref":"HAP.Characteristics.Saturation.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.Saturation.type/0","doc":"","ref":"HAP.Characteristics.Saturation.html#type/0"},{"type":"function","title":"HAP.Characteristics.Saturation.unit/0","doc":"","ref":"HAP.Characteristics.Saturation.html#unit/0"},{"type":"module","title":"HAP.Characteristics.SerialNumber","doc":"Definition of the `public.hap.characteristic.serial-number` characteristic","ref":"HAP.Characteristics.SerialNumber.html"},{"type":"function","title":"HAP.Characteristics.SerialNumber.format/0","doc":"","ref":"HAP.Characteristics.SerialNumber.html#format/0"},{"type":"function","title":"HAP.Characteristics.SerialNumber.max_length/0","doc":"","ref":"HAP.Characteristics.SerialNumber.html#max_length/0"},{"type":"function","title":"HAP.Characteristics.SerialNumber.perms/0","doc":"","ref":"HAP.Characteristics.SerialNumber.html#perms/0"},{"type":"function","title":"HAP.Characteristics.SerialNumber.type/0","doc":"","ref":"HAP.Characteristics.SerialNumber.html#type/0"},{"type":"module","title":"HAP.Characteristics.ServiceLabelIndex","doc":"Definition of the `public.hap.characteristic.service-label-index` characteristic","ref":"HAP.Characteristics.ServiceLabelIndex.html"},{"type":"function","title":"HAP.Characteristics.ServiceLabelIndex.format/0","doc":"","ref":"HAP.Characteristics.ServiceLabelIndex.html#format/0"},{"type":"function","title":"HAP.Characteristics.ServiceLabelIndex.min_value/0","doc":"","ref":"HAP.Characteristics.ServiceLabelIndex.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.ServiceLabelIndex.perms/0","doc":"","ref":"HAP.Characteristics.ServiceLabelIndex.html#perms/0"},{"type":"function","title":"HAP.Characteristics.ServiceLabelIndex.step_value/0","doc":"","ref":"HAP.Characteristics.ServiceLabelIndex.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.ServiceLabelIndex.type/0","doc":"","ref":"HAP.Characteristics.ServiceLabelIndex.html#type/0"},{"type":"module","title":"HAP.Characteristics.ServiceLabelNamespace","doc":"Definition of the `public.hap.characteristic.service-label-namespace` characteristic\n\nValid Values\n0 ”Dots. For e.g ”.” ”..” ”...” ”....””\n1 ”Arabic numerals. For e.g. 0,1,2,3”","ref":"HAP.Characteristics.ServiceLabelNamespace.html"},{"type":"function","title":"HAP.Characteristics.ServiceLabelNamespace.format/0","doc":"","ref":"HAP.Characteristics.ServiceLabelNamespace.html#format/0"},{"type":"function","title":"HAP.Characteristics.ServiceLabelNamespace.max_value/0","doc":"","ref":"HAP.Characteristics.ServiceLabelNamespace.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.ServiceLabelNamespace.min_value/0","doc":"","ref":"HAP.Characteristics.ServiceLabelNamespace.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.ServiceLabelNamespace.perms/0","doc":"","ref":"HAP.Characteristics.ServiceLabelNamespace.html#perms/0"},{"type":"function","title":"HAP.Characteristics.ServiceLabelNamespace.step_value/0","doc":"","ref":"HAP.Characteristics.ServiceLabelNamespace.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.ServiceLabelNamespace.type/0","doc":"","ref":"HAP.Characteristics.ServiceLabelNamespace.html#type/0"},{"type":"module","title":"HAP.Characteristics.SlatType","doc":"Definition of the `public.hap.characteristic.type.slat` characteristic\n\nValid values:\n\n0 Horizontal\n1 Vertical","ref":"HAP.Characteristics.SlatType.html"},{"type":"function","title":"HAP.Characteristics.SlatType.format/0","doc":"","ref":"HAP.Characteristics.SlatType.html#format/0"},{"type":"function","title":"HAP.Characteristics.SlatType.max_value/0","doc":"","ref":"HAP.Characteristics.SlatType.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.SlatType.min_value/0","doc":"","ref":"HAP.Characteristics.SlatType.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.SlatType.perms/0","doc":"","ref":"HAP.Characteristics.SlatType.html#perms/0"},{"type":"function","title":"HAP.Characteristics.SlatType.step_value/0","doc":"","ref":"HAP.Characteristics.SlatType.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.SlatType.type/0","doc":"","ref":"HAP.Characteristics.SlatType.html#type/0"},{"type":"module","title":"HAP.Characteristics.SmokeDetected","doc":"Definition of the `public.hap.characteristic.smoke-detected` characteristic\n\nValid values:\n0: Smoke is not detected\n1: Smoke is detected","ref":"HAP.Characteristics.SmokeDetected.html"},{"type":"function","title":"HAP.Characteristics.SmokeDetected.format/0","doc":"","ref":"HAP.Characteristics.SmokeDetected.html#format/0"},{"type":"function","title":"HAP.Characteristics.SmokeDetected.max_value/0","doc":"","ref":"HAP.Characteristics.SmokeDetected.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.SmokeDetected.min_value/0","doc":"","ref":"HAP.Characteristics.SmokeDetected.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.SmokeDetected.perms/0","doc":"","ref":"HAP.Characteristics.SmokeDetected.html#perms/0"},{"type":"function","title":"HAP.Characteristics.SmokeDetected.step_value/0","doc":"","ref":"HAP.Characteristics.SmokeDetected.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.SmokeDetected.type/0","doc":"","ref":"HAP.Characteristics.SmokeDetected.html#type/0"},{"type":"module","title":"HAP.Characteristics.StatusActive","doc":"Definition of the `public.hap.characteristic.status-active` characteristic","ref":"HAP.Characteristics.StatusActive.html"},{"type":"function","title":"HAP.Characteristics.StatusActive.format/0","doc":"","ref":"HAP.Characteristics.StatusActive.html#format/0"},{"type":"function","title":"HAP.Characteristics.StatusActive.perms/0","doc":"","ref":"HAP.Characteristics.StatusActive.html#perms/0"},{"type":"function","title":"HAP.Characteristics.StatusActive.type/0","doc":"","ref":"HAP.Characteristics.StatusActive.html#type/0"},{"type":"module","title":"HAP.Characteristics.StatusFault","doc":"Definition of the `public.hap.characteristic.status-fault` characteristic\n\nA non-zero value indicates that the accessory has experienced a fault that \nmay be interfering with its intended functionality. A value of 0 indicates \nthat there is no fault.","ref":"HAP.Characteristics.StatusFault.html"},{"type":"function","title":"HAP.Characteristics.StatusFault.format/0","doc":"","ref":"HAP.Characteristics.StatusFault.html#format/0"},{"type":"function","title":"HAP.Characteristics.StatusFault.max_value/0","doc":"","ref":"HAP.Characteristics.StatusFault.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.StatusFault.min_value/0","doc":"","ref":"HAP.Characteristics.StatusFault.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.StatusFault.perms/0","doc":"","ref":"HAP.Characteristics.StatusFault.html#perms/0"},{"type":"function","title":"HAP.Characteristics.StatusFault.step_value/0","doc":"","ref":"HAP.Characteristics.StatusFault.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.StatusFault.type/0","doc":"","ref":"HAP.Characteristics.StatusFault.html#type/0"},{"type":"module","title":"HAP.Characteristics.StatusLowBattery","doc":"Definition of the `public.hap.characteristic.status-lo-batt` characteristic\n\nA status of 1 indicates that the battery level of the accessory is low. \nValue should return to 0 when the battery charges to a level that's above the \nlow threshold.","ref":"HAP.Characteristics.StatusLowBattery.html"},{"type":"function","title":"HAP.Characteristics.StatusLowBattery.format/0","doc":"","ref":"HAP.Characteristics.StatusLowBattery.html#format/0"},{"type":"function","title":"HAP.Characteristics.StatusLowBattery.max_value/0","doc":"","ref":"HAP.Characteristics.StatusLowBattery.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.StatusLowBattery.min_value/0","doc":"","ref":"HAP.Characteristics.StatusLowBattery.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.StatusLowBattery.perms/0","doc":"","ref":"HAP.Characteristics.StatusLowBattery.html#perms/0"},{"type":"function","title":"HAP.Characteristics.StatusLowBattery.step_value/0","doc":"","ref":"HAP.Characteristics.StatusLowBattery.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.StatusLowBattery.type/0","doc":"","ref":"HAP.Characteristics.StatusLowBattery.html#type/0"},{"type":"module","title":"HAP.Characteristics.StatusTampered","doc":"Definition of the `public.hap.characteristic.status-tampered` characteristic\n\nThis characteristic describes an accessory which has been tampered with. \nA status of 1 indicates that the accessory has been tampered with. Value \nshould return to 0 when the accessory has been reset to a non-tampered state.","ref":"HAP.Characteristics.StatusTampered.html"},{"type":"function","title":"HAP.Characteristics.StatusTampered.format/0","doc":"","ref":"HAP.Characteristics.StatusTampered.html#format/0"},{"type":"function","title":"HAP.Characteristics.StatusTampered.max_value/0","doc":"","ref":"HAP.Characteristics.StatusTampered.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.StatusTampered.min_value/0","doc":"","ref":"HAP.Characteristics.StatusTampered.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.StatusTampered.perms/0","doc":"","ref":"HAP.Characteristics.StatusTampered.html#perms/0"},{"type":"function","title":"HAP.Characteristics.StatusTampered.step_value/0","doc":"","ref":"HAP.Characteristics.StatusTampered.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.StatusTampered.type/0","doc":"","ref":"HAP.Characteristics.StatusTampered.html#type/0"},{"type":"module","title":"HAP.Characteristics.SulphurDioxideDensity","doc":"Definition of the `public.hap.characteristic.density.so2` characteristic","ref":"HAP.Characteristics.SulphurDioxideDensity.html"},{"type":"function","title":"HAP.Characteristics.SulphurDioxideDensity.format/0","doc":"","ref":"HAP.Characteristics.SulphurDioxideDensity.html#format/0"},{"type":"function","title":"HAP.Characteristics.SulphurDioxideDensity.max_value/0","doc":"","ref":"HAP.Characteristics.SulphurDioxideDensity.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.SulphurDioxideDensity.min_value/0","doc":"","ref":"HAP.Characteristics.SulphurDioxideDensity.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.SulphurDioxideDensity.perms/0","doc":"","ref":"HAP.Characteristics.SulphurDioxideDensity.html#perms/0"},{"type":"function","title":"HAP.Characteristics.SulphurDioxideDensity.type/0","doc":"","ref":"HAP.Characteristics.SulphurDioxideDensity.html#type/0"},{"type":"module","title":"HAP.Characteristics.SwingMode","doc":"Definition of the `public.hap.characteristic.swing-mode` characteristic\n\nValid values:\n\n0: Swing disabled\n1: Swing enabled","ref":"HAP.Characteristics.SwingMode.html"},{"type":"function","title":"HAP.Characteristics.SwingMode.format/0","doc":"","ref":"HAP.Characteristics.SwingMode.html#format/0"},{"type":"function","title":"HAP.Characteristics.SwingMode.max_value/0","doc":"","ref":"HAP.Characteristics.SwingMode.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.SwingMode.min_value/0","doc":"","ref":"HAP.Characteristics.SwingMode.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.SwingMode.perms/0","doc":"","ref":"HAP.Characteristics.SwingMode.html#perms/0"},{"type":"function","title":"HAP.Characteristics.SwingMode.step_value/0","doc":"","ref":"HAP.Characteristics.SwingMode.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.SwingMode.type/0","doc":"","ref":"HAP.Characteristics.SwingMode.html#type/0"},{"type":"module","title":"HAP.Characteristics.TargetAirPurifierState","doc":"Definition of the `public.hap.characteristic.air-purifier.state.target` characteristic\n\nValid values:\n\n0 Manual\n1 Auto","ref":"HAP.Characteristics.TargetAirPurifierState.html"},{"type":"function","title":"HAP.Characteristics.TargetAirPurifierState.format/0","doc":"","ref":"HAP.Characteristics.TargetAirPurifierState.html#format/0"},{"type":"function","title":"HAP.Characteristics.TargetAirPurifierState.max_value/0","doc":"","ref":"HAP.Characteristics.TargetAirPurifierState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.TargetAirPurifierState.min_value/0","doc":"","ref":"HAP.Characteristics.TargetAirPurifierState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.TargetAirPurifierState.perms/0","doc":"","ref":"HAP.Characteristics.TargetAirPurifierState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.TargetAirPurifierState.step_value/0","doc":"","ref":"HAP.Characteristics.TargetAirPurifierState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.TargetAirPurifierState.type/0","doc":"","ref":"HAP.Characteristics.TargetAirPurifierState.html#type/0"},{"type":"module","title":"HAP.Characteristics.TargetDoorState","doc":"Definition of the `public.hap.characteristic.door-state.target` characteristic\n\nValid values:\n\n0 Open    - The door is fully open\n1 Closed  - The door is fully closed","ref":"HAP.Characteristics.TargetDoorState.html"},{"type":"function","title":"HAP.Characteristics.TargetDoorState.format/0","doc":"","ref":"HAP.Characteristics.TargetDoorState.html#format/0"},{"type":"function","title":"HAP.Characteristics.TargetDoorState.max_value/0","doc":"","ref":"HAP.Characteristics.TargetDoorState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.TargetDoorState.min_value/0","doc":"","ref":"HAP.Characteristics.TargetDoorState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.TargetDoorState.perms/0","doc":"","ref":"HAP.Characteristics.TargetDoorState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.TargetDoorState.step_value/0","doc":"","ref":"HAP.Characteristics.TargetDoorState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.TargetDoorState.type/0","doc":"","ref":"HAP.Characteristics.TargetDoorState.html#type/0"},{"type":"module","title":"HAP.Characteristics.TargetFanState","doc":"Definition of the `public.hap.characteristic.fan.state.target` characteristic\n\nValid values:\n\n0 Manual\n1 Auto","ref":"HAP.Characteristics.TargetFanState.html"},{"type":"function","title":"HAP.Characteristics.TargetFanState.format/0","doc":"","ref":"HAP.Characteristics.TargetFanState.html#format/0"},{"type":"function","title":"HAP.Characteristics.TargetFanState.max_value/0","doc":"","ref":"HAP.Characteristics.TargetFanState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.TargetFanState.min_value/0","doc":"","ref":"HAP.Characteristics.TargetFanState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.TargetFanState.perms/0","doc":"","ref":"HAP.Characteristics.TargetFanState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.TargetFanState.step_value/0","doc":"","ref":"HAP.Characteristics.TargetFanState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.TargetFanState.type/0","doc":"","ref":"HAP.Characteristics.TargetFanState.html#type/0"},{"type":"module","title":"HAP.Characteristics.TargetHeaterCoolerState","doc":"Definition of the `public.hap.characteristic.heater-cooler.target` characteristic\n\nValid values: \n\n0 Off\n1 Heat (if current temperature is below the target temperature then turn on heating)\n2 Cooling (if current temperature is above the target temperature then turn on cooling)\n3 Auto (turn on heating or cooling to maintain temperature within the target temperatures)","ref":"HAP.Characteristics.TargetHeaterCoolerState.html"},{"type":"function","title":"HAP.Characteristics.TargetHeaterCoolerState.format/0","doc":"","ref":"HAP.Characteristics.TargetHeaterCoolerState.html#format/0"},{"type":"function","title":"HAP.Characteristics.TargetHeaterCoolerState.max_value/0","doc":"","ref":"HAP.Characteristics.TargetHeaterCoolerState.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.TargetHeaterCoolerState.min_value/0","doc":"","ref":"HAP.Characteristics.TargetHeaterCoolerState.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.TargetHeaterCoolerState.perms/0","doc":"","ref":"HAP.Characteristics.TargetHeaterCoolerState.html#perms/0"},{"type":"function","title":"HAP.Characteristics.TargetHeaterCoolerState.step_value/0","doc":"","ref":"HAP.Characteristics.TargetHeaterCoolerState.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.TargetHeaterCoolerState.type/0","doc":"","ref":"HAP.Characteristics.TargetHeaterCoolerState.html#type/0"},{"type":"module","title":"HAP.Characteristics.TargetHorizontalTiltAngle","doc":"Definition of the `public.hap.characteristic.horizontal-tilt.target` characteristic","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html"},{"type":"function","title":"HAP.Characteristics.TargetHorizontalTiltAngle.format/0","doc":"","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#format/0"},{"type":"function","title":"HAP.Characteristics.TargetHorizontalTiltAngle.max_value/0","doc":"","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.TargetHorizontalTiltAngle.min_value/0","doc":"","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.TargetHorizontalTiltAngle.perms/0","doc":"","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#perms/0"},{"type":"function","title":"HAP.Characteristics.TargetHorizontalTiltAngle.step_value/0","doc":"","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.TargetHorizontalTiltAngle.type/0","doc":"","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#type/0"},{"type":"function","title":"HAP.Characteristics.TargetHorizontalTiltAngle.units/0","doc":"","ref":"HAP.Characteristics.TargetHorizontalTiltAngle.html#units/0"},{"type":"module","title":"HAP.Characteristics.TargetPosition","doc":"Definition of the `public.hap.characteristic.position.target` characteristic","ref":"HAP.Characteristics.TargetPosition.html"},{"type":"function","title":"HAP.Characteristics.TargetPosition.format/0","doc":"","ref":"HAP.Characteristics.TargetPosition.html#format/0"},{"type":"function","title":"HAP.Characteristics.TargetPosition.max_value/0","doc":"","ref":"HAP.Characteristics.TargetPosition.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.TargetPosition.min_value/0","doc":"","ref":"HAP.Characteristics.TargetPosition.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.TargetPosition.perms/0","doc":"","ref":"HAP.Characteristics.TargetPosition.html#perms/0"},{"type":"function","title":"HAP.Characteristics.TargetPosition.step_value/0","doc":"","ref":"HAP.Characteristics.TargetPosition.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.TargetPosition.type/0","doc":"","ref":"HAP.Characteristics.TargetPosition.html#type/0"},{"type":"function","title":"HAP.Characteristics.TargetPosition.unit/0","doc":"","ref":"HAP.Characteristics.TargetPosition.html#unit/0"},{"type":"module","title":"HAP.Characteristics.TargetRelativeHumidity","doc":"Definition of the `public.hap.characteristic.relative.humidity.target` characteristic","ref":"HAP.Characteristics.TargetRelativeHumidity.html"},{"type":"function","title":"HAP.Characteristics.TargetRelativeHumidity.format/0","doc":"","ref":"HAP.Characteristics.TargetRelativeHumidity.html#format/0"},{"type":"function","title":"HAP.Characteristics.TargetRelativeHumidity.max_value/0","doc":"","ref":"HAP.Characteristics.TargetRelativeHumidity.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.TargetRelativeHumidity.min_value/0","doc":"","ref":"HAP.Characteristics.TargetRelativeHumidity.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.TargetRelativeHumidity.perms/0","doc":"","ref":"HAP.Characteristics.TargetRelativeHumidity.html#perms/0"},{"type":"function","title":"HAP.Characteristics.TargetRelativeHumidity.step_value/0","doc":"","ref":"HAP.Characteristics.TargetRelativeHumidity.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.TargetRelativeHumidity.type/0","doc":"","ref":"HAP.Characteristics.TargetRelativeHumidity.html#type/0"},{"type":"module","title":"HAP.Characteristics.TargetTemperature","doc":"Definition of the `public.hap.characteristic.temperature.target` characteristic","ref":"HAP.Characteristics.TargetTemperature.html"},{"type":"function","title":"HAP.Characteristics.TargetTemperature.format/0","doc":"","ref":"HAP.Characteristics.TargetTemperature.html#format/0"},{"type":"function","title":"HAP.Characteristics.TargetTemperature.max_value/0","doc":"","ref":"HAP.Characteristics.TargetTemperature.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.TargetTemperature.min_value/0","doc":"","ref":"HAP.Characteristics.TargetTemperature.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.TargetTemperature.perms/0","doc":"","ref":"HAP.Characteristics.TargetTemperature.html#perms/0"},{"type":"function","title":"HAP.Characteristics.TargetTemperature.step_value/0","doc":"","ref":"HAP.Characteristics.TargetTemperature.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.TargetTemperature.type/0","doc":"","ref":"HAP.Characteristics.TargetTemperature.html#type/0"},{"type":"module","title":"HAP.Characteristics.TargetTiltAngle","doc":"Definition of the `public.hap.characteristic.tilt.target` characteristic","ref":"HAP.Characteristics.TargetTiltAngle.html"},{"type":"function","title":"HAP.Characteristics.TargetTiltAngle.format/0","doc":"","ref":"HAP.Characteristics.TargetTiltAngle.html#format/0"},{"type":"function","title":"HAP.Characteristics.TargetTiltAngle.max_value/0","doc":"","ref":"HAP.Characteristics.TargetTiltAngle.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.TargetTiltAngle.min_value/0","doc":"","ref":"HAP.Characteristics.TargetTiltAngle.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.TargetTiltAngle.perms/0","doc":"","ref":"HAP.Characteristics.TargetTiltAngle.html#perms/0"},{"type":"function","title":"HAP.Characteristics.TargetTiltAngle.step_value/0","doc":"","ref":"HAP.Characteristics.TargetTiltAngle.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.TargetTiltAngle.type/0","doc":"","ref":"HAP.Characteristics.TargetTiltAngle.html#type/0"},{"type":"function","title":"HAP.Characteristics.TargetTiltAngle.units/0","doc":"","ref":"HAP.Characteristics.TargetTiltAngle.html#units/0"},{"type":"module","title":"HAP.Characteristics.TargetVerticalTiltAngle","doc":"Definition of the `public.hap.characteristic.vertical-tilt.target` characteristic","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html"},{"type":"function","title":"HAP.Characteristics.TargetVerticalTiltAngle.format/0","doc":"","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#format/0"},{"type":"function","title":"HAP.Characteristics.TargetVerticalTiltAngle.max_value/0","doc":"","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.TargetVerticalTiltAngle.min_value/0","doc":"","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.TargetVerticalTiltAngle.perms/0","doc":"","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#perms/0"},{"type":"function","title":"HAP.Characteristics.TargetVerticalTiltAngle.step_value/0","doc":"","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.TargetVerticalTiltAngle.type/0","doc":"","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#type/0"},{"type":"function","title":"HAP.Characteristics.TargetVerticalTiltAngle.units/0","doc":"","ref":"HAP.Characteristics.TargetVerticalTiltAngle.html#units/0"},{"type":"module","title":"HAP.Characteristics.TemperatureDisplayUnits","doc":"Definition of the `public.hap.characteristic.temperature.units` characteristic\n\nValid values:\n\n0: Celsius\n1: Fahrenheit","ref":"HAP.Characteristics.TemperatureDisplayUnits.html"},{"type":"function","title":"HAP.Characteristics.TemperatureDisplayUnits.format/0","doc":"","ref":"HAP.Characteristics.TemperatureDisplayUnits.html#format/0"},{"type":"function","title":"HAP.Characteristics.TemperatureDisplayUnits.max_value/0","doc":"","ref":"HAP.Characteristics.TemperatureDisplayUnits.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.TemperatureDisplayUnits.min_value/0","doc":"","ref":"HAP.Characteristics.TemperatureDisplayUnits.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.TemperatureDisplayUnits.perms/0","doc":"","ref":"HAP.Characteristics.TemperatureDisplayUnits.html#perms/0"},{"type":"function","title":"HAP.Characteristics.TemperatureDisplayUnits.step_value/0","doc":"","ref":"HAP.Characteristics.TemperatureDisplayUnits.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.TemperatureDisplayUnits.type/0","doc":"","ref":"HAP.Characteristics.TemperatureDisplayUnits.html#type/0"},{"type":"module","title":"HAP.Characteristics.VOCDensity","doc":"Definition of the `public.hap.characteristic.density.voc` characteristic","ref":"HAP.Characteristics.VOCDensity.html"},{"type":"function","title":"HAP.Characteristics.VOCDensity.format/0","doc":"","ref":"HAP.Characteristics.VOCDensity.html#format/0"},{"type":"function","title":"HAP.Characteristics.VOCDensity.max_value/0","doc":"","ref":"HAP.Characteristics.VOCDensity.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.VOCDensity.min_value/0","doc":"","ref":"HAP.Characteristics.VOCDensity.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.VOCDensity.perms/0","doc":"","ref":"HAP.Characteristics.VOCDensity.html#perms/0"},{"type":"function","title":"HAP.Characteristics.VOCDensity.type/0","doc":"","ref":"HAP.Characteristics.VOCDensity.html#type/0"},{"type":"module","title":"HAP.Characteristics.Version","doc":"Definition of the `public.hap.characteristic.version` characteristic","ref":"HAP.Characteristics.Version.html"},{"type":"function","title":"HAP.Characteristics.Version.format/0","doc":"","ref":"HAP.Characteristics.Version.html#format/0"},{"type":"function","title":"HAP.Characteristics.Version.max_length/0","doc":"","ref":"HAP.Characteristics.Version.html#max_length/0"},{"type":"function","title":"HAP.Characteristics.Version.perms/0","doc":"","ref":"HAP.Characteristics.Version.html#perms/0"},{"type":"function","title":"HAP.Characteristics.Version.type/0","doc":"","ref":"HAP.Characteristics.Version.html#type/0"},{"type":"module","title":"HAP.Characteristics.Volume","doc":"Definition of the `public.hap.characteristic.volume` characteristic","ref":"HAP.Characteristics.Volume.html"},{"type":"function","title":"HAP.Characteristics.Volume.format/0","doc":"","ref":"HAP.Characteristics.Volume.html#format/0"},{"type":"function","title":"HAP.Characteristics.Volume.max_value/0","doc":"","ref":"HAP.Characteristics.Volume.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.Volume.min_value/0","doc":"","ref":"HAP.Characteristics.Volume.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.Volume.perms/0","doc":"","ref":"HAP.Characteristics.Volume.html#perms/0"},{"type":"function","title":"HAP.Characteristics.Volume.step_value/0","doc":"","ref":"HAP.Characteristics.Volume.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.Volume.type/0","doc":"","ref":"HAP.Characteristics.Volume.html#type/0"},{"type":"function","title":"HAP.Characteristics.Volume.unit/0","doc":"","ref":"HAP.Characteristics.Volume.html#unit/0"},{"type":"module","title":"HAP.Characteristics.WaterLevel","doc":"Definition of the `public.hap.characteristic.water-level` characteristic","ref":"HAP.Characteristics.WaterLevel.html"},{"type":"function","title":"HAP.Characteristics.WaterLevel.format/0","doc":"","ref":"HAP.Characteristics.WaterLevel.html#format/0"},{"type":"function","title":"HAP.Characteristics.WaterLevel.max_value/0","doc":"","ref":"HAP.Characteristics.WaterLevel.html#max_value/0"},{"type":"function","title":"HAP.Characteristics.WaterLevel.min_value/0","doc":"","ref":"HAP.Characteristics.WaterLevel.html#min_value/0"},{"type":"function","title":"HAP.Characteristics.WaterLevel.perms/0","doc":"","ref":"HAP.Characteristics.WaterLevel.html#perms/0"},{"type":"function","title":"HAP.Characteristics.WaterLevel.step_value/0","doc":"","ref":"HAP.Characteristics.WaterLevel.html#step_value/0"},{"type":"function","title":"HAP.Characteristics.WaterLevel.type/0","doc":"","ref":"HAP.Characteristics.WaterLevel.html#type/0"},{"type":"function","title":"HAP.Characteristics.WaterLevel.unit/0","doc":"","ref":"HAP.Characteristics.WaterLevel.html#unit/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}